
# q-expansion of newform 4004.2.a.h, downloaded from the LMFDB on 07 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 4004
weight = 2
poly_data = [-14, 189, 288, -249, -247, 116, 51, -19, -3, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0], 1], [[36543, 141008, 26935, -132924, -11387, 27349, 1071, -1526, -11], 15311], [[-10711, 55726, -19277, -46071, 7323, 7131, -916, -296, 38], 15311], [[29301, -69971, -61523, 86853, 18710, -20218, -1987, 1230, 49], 15311], [[103366, 16827, -117092, -30967, 25963, 10172, -2290, -740, 95], 15311], [[-41874, -64309, 7997, -14361, 32800, 9491, -9449, -847, 626], 15311], [[17363, -169631, 30557, 121814, -47446, -23753, 11281, 1439, -702], 15311], [[-70160, -81863, 192431, 127655, -110094, -31010, 18764, 1985, -979], 15311]]

hecke_ring_character_values = None
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -1, 0, 0, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0, 0], [-1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, -1, 0, 0, 0, 0, 1], [1, 0, -1, 0, 1, 0, 0, 0, 0], [1, -1, 0, 0, 0, 1, 0, 0, 1], [1, 1, 0, 0, -1, 0, -1, -1, 0], [2, 0, 1, 0, 1, -1, 0, -1, -2], [0, 0, 0, -1, -1, 0, 0, 0, -1], [2, -1, 1, -1, -1, -1, 0, -1, 0], [0, 1, 1, -1, 0, -1, 0, 1, 1], [1, 1, 0, 0, -2, 1, 0, 0, -1], [3, 1, -1, 1, -3, 0, 1, -1, -1], [3, -1, 1, 0, 0, 1, -1, -2, 0], [5, -2, 1, 0, 1, 0, 1, -1, 1], [1, 0, -1, -1, 2, 0, 1, 1, 0], [0, 1, 1, 0, 1, 1, 0, 0, 1], [0, 2, -1, 1, 0, -1, 0, 3, -1], [-4, 1, 1, -1, 1, 0, -1, -2, -1], [2, -1, 0, 1, 1, 2, 0, 1, 0], [0, 0, 2, 0, 1, -2, 0, 0, 1], [2, -1, 2, -1, 2, 0, 0, 0, 0], [2, -2, -2, 0, 0, -1, 1, 2, 1], [3, 0, 2, -2, 2, 0, 1, -1, 1], [1, 0, 1, -3, 4, -2, 2, 1, 2], [3, -3, 2, 1, 2, -1, 2, 0, 0], [3, 1, -2, 0, 0, 0, 1, 2, 0], [0, 0, -1, 0, 3, 2, 1, 0, 1], [2, 1, -1, -1, 1, 1, 0, -3, 0], [-3, 1, 1, -2, -3, -2, 0, -1, -1], [4, -2, -2, 1, 1, 2, -2, 0, -1], [0, -4, 3, -3, 3, -1, 0, -1, 1], [5, -4, 2, 0, 5, -1, 0, -2, 0], [3, -1, 1, 3, -3, 1, -1, 0, -1], [-1, 4, 0, 1, 0, -2, -1, 2, 0], [0, -1, 1, 2, 0, 0, 0, 2, 1], [0, 2, -6, 2, -3, 2, -2, 3, 0], [0, -2, -1, 1, -1, -2, 1, 0, 0], [7, -3, 3, 0, 1, 0, 0, -1, -1], [6, -1, 1, 0, 3, 0, 1, 0, -2], [0, -3, -2, 1, -3, 0, -2, 0, -1], [2, -5, 4, 0, -1, -1, -1, -1, -1], [0, 2, 1, -1, 2, 0, 1, -2, -2], [-2, 2, 2, -4, 1, 0, -2, -2, -1], [0, -5, 0, -2, -1, -2, 0, -2, 1], [1, 1, 0, 5, 2, 1, -1, 2, -1], [4, -3, 0, 0, 4, 4, 0, -2, 3], [0, 0, -3, 3, -3, 4, -1, 0, 2], [-3, -2, 2, 1, 3, 0, 1, 1, -2], [-2, 0, 1, -2, -1, -1, 2, 3, 0], [3, -2, -3, 2, -2, 3, 1, 2, 3], [-1, 0, 2, -2, 4, -2, -3, -3, -3], [-5, -1, -3, 1, -1, 2, 0, 1, 0], [2, 2, -2, -3, -3, 0, -2, 2, 3], [-1, -1, -2, 0, -1, -1, -1, 2, 0], [-11, 0, 1, -2, 3, -1, -3, 0, -1], [5, -1, 0, 1, -2, -1, 0, 2, -3], [8, -4, -2, 2, -3, 1, 1, 3, 3], [2, -2, -1, 2, 1, 1, 4, 1, 2], [7, -3, 1, -3, 5, -2, -1, 1, 1], [5, -5, 0, 3, -4, 1, 2, 0, 0], [-3, 5, -3, 1, 0, 0, 0, 3, 4], [-7, -3, 1, -5, -2, 0, -2, -5, 0], [-5, 1, -3, 1, 0, 3, -3, 1, -1], [-1, -1, -2, -3, 3, 1, -2, 0, 2], [-2, -2, 5, -2, -1, -2, -1, -2, -3], [11, -3, -2, 1, 2, -2, 3, 1, -1], [6, -8, 4, -2, 2, 0, 2, -4, 0], [-3, -1, -1, 3, -4, 2, 2, -3, 0], [5, 1, 2, -4, 0, 2, -1, -1, -1], [2, -5, 7, -2, 1, -4, -1, 0, 0], [3, 4, -3, 3, 1, 1, -2, 0, -3], [-5, 5, -1, 3, -1, -3, 1, 2, -3], [-8, 6, -4, -1, 0, -2, 2, 5, -1], [-8, 1, 1, -1, 2, 1, 2, 3, -1], [-1, 2, 0, 1, -4, -1, -4, 0, -1], [5, -4, 3, 3, -2, 3, 1, -2, 0], [4, 1, 0, 4, -4, 0, -2, -2, 0], [12, 2, 0, 2, -1, -1, 1, 1, 1], [-11, 4, 0, 1, 0, 1, 0, 4, 3], [7, 0, 4, 1, 2, 1, -2, 2, 1], [-3, -2, 2, 0, -5, 1, 0, 0, 2], [-11, 2, -3, -1, -2, -3, -1, 0, -2], [-3, 7, 1, -1, -3, -1, 1, 0, -1], [0, 0, -1, 1, -3, -1, 2, 7, 1], [8, -6, 0, 3, -1, 2, -2, 0, 1], [6, -5, 7, -1, 4, -2, 1, -2, -3], [-5, 4, 3, 1, 2, 2, 0, -1, -4], [4, -4, 1, 2, -2, -1, 0, 0, 2], [-5, -2, -2, 1, 2, 1, 2, -2, 1], [-4, -6, 2, -3, 2, -3, 3, -1, 4], [4, 1, 3, 1, -3, -2, 1, 1, -3], [6, -4, 0, 8, -5, 1, -1, 1, -3], [-3, -4, 3, 2, 5, 1, 5, 2, 1], [3, 5, -3, 1, -1, 1, -5, -2, -5], [0, 7, -1, -4, 2, -1, -2, -1, 1], [5, 3, -1, -3, 2, -2, 0, 1, -2], [-2, -7, 2, -1, 4, 4, 0, 0, 0], [1, -3, -4, 4, -4, 0, 1, 3, 4], [-12, 0, 0, -2, 5, 1, -1, 1, 5], [4, 1, -2, -1, 0, 0, -4, -2, -2], [-3, 4, -2, 6, 2, 1, 0, 2, 0], [-9, 9, -2, -6, 2, 0, -3, 3, 3], [5, 0, -5, -2, 5, 5, -1, -2, 1], [-10, 0, 1, -5, -2, -3, 0, 1, 3], [-15, 2, -3, 2, 2, 0, 2, 1, 2], [11, -1, 2, -5, 2, -3, 3, 2, 3], [-2, 8, -2, 3, -6, -1, 1, 3, -2], [-1, -3, 3, 8, 1, 0, -2, -1, -5], [-1, 4, -2, 2, -1, 5, -4, 4, 0], [14, -7, 1, 6, -6, 3, 0, -1, -1], [-10, 2, -5, -6, -1, -2, -4, 0, 2], [-7, 0, -2, -2, -4, 3, -3, -2, 5], [14, 6, -2, 3, -3, -2, 2, 0, -5], [7, -1, -1, 0, 4, 3, 3, 0, 2], [-2, 4, -3, -2, 1, -2, 0, 4, 2], [-4, 6, -2, 1, -5, 1, -5, -1, 1], [10, -4, 2, 4, 3, 0, 2, 2, -4], [-10, 5, -6, 2, -2, 1, -3, 5, 2], [2, 2, 1, 2, 1, 0, -4, 2, 2], [-6, -1, 0, 2, -1, -3, 2, -1, -3], [-1, -1, -6, -1, -2, 2, 3, 1, 3], [-2, 0, 5, -4, 4, 2, -1, 0, 5], [2, 3, -5, -3, 1, 1, 0, -5, -2], [-4, -5, 2, -2, 5, 1, 3, -7, 5], [7, -1, -8, 3, -5, -2, 1, 5, -1], [-7, -1, 2, 3, 3, -1, -2, 0, -2], [1, -3, -1, 2, -2, -3, 1, -2, -6], [-3, 0, 4, 5, -8, 1, -2, -2, -5], [-8, -3, 0, 0, 3, 0, 2, 2, -1], [-1, 11, -8, 1, 1, -2, -3, 6, -1], [-15, 4, 5, 1, 1, -2, 0, -3, 1], [-8, 5, -6, -3, -2, 0, 0, 2, 0], [-4, -6, 1, -2, 3, -4, 3, 4, 0], [10, 1, -1, 2, 5, -1, 3, 5, 4], [-4, 5, 1, 1, -4, 0, 3, -2, -5], [-5, 9, -2, -1, -2, 4, -5, 3, 1], [3, -7, 5, 5, 4, -1, -1, -1, -5], [-7, -8, 3, 4, 0, 3, -1, -6, -6], [-12, -9, 5, -1, 5, 1, 4, 1, 0], [11, -9, 7, -3, 4, 2, 2, -5, 2], [14, -3, -1, 4, 0, -3, 4, 5, 3], [3, -4, 4, -1, -4, 1, 0, -6, -5], [24, 6, -1, 1, 0, -1, 2, 1, -3], [1, 8, -2, 1, -1, 1, -2, 1, 1], [12, -3, 1, 1, 0, 2, 5, 2, 7], [-3, -1, -3, 0, 4, 3, 3, 4, 8], [12, 0, -1, 2, 2, 3, -2, 3, 3], [29, -7, -1, 4, 1, 0, 2, -1, 3], [-1, 6, -2, 3, 2, 3, -2, 2, -1], [-12, -1, 1, 1, 1, 3, 0, -1, -2], [-11, -12, 7, 0, 0, 4, 2, -9, -4], [0, 0, -3, 6, 0, 2, -3, 2, -3], [7, -5, -4, 3, 5, 8, -1, -1, 4], [-13, 12, -2, -3, -5, -1, -2, -4, 0], [-8, 8, 2, -1, -7, -5, -5, 2, 0], [9, -3, -4, -1, -3, -1, -2, 0, -4], [-6, 1, -2, 2, 1, -1, 0, 5, 1], [-7, 6, -11, 5, -9, 0, -2, 5, -1], [-10, 1, -1, 2, -9, -2, 3, 4, 0], [22, -4, 5, 4, -4, 1, 0, -7, 0], [-19, 3, -3, 8, -5, -4, 2, 1, -3], [9, 1, 0, -3, 7, -5, 0, 0, -6], [-4, -2, 6, -4, 4, -8, 2, 2, 2], [14, -5, 9, 4, 0, 2, -3, -7, 0], [16, -2, 9, -7, 10, -4, 3, -2, -2], [3, -5, -1, 7, -4, 8, 0, -1, 0], [-4, -5, -3, 2, 3, 0, 5, 4, 4], [3, 0, 2, 1, 2, 3, 0, -6, 1], [-12, -6, 0, 0, 3, 0, 6, 0, 4], [-11, -3, 0, 8, -7, 3, 0, 2, 0], [8, 8, -3, 4, -13, -2, 1, 0, -4], [9, -2, 4, -6, 3, -5, -2, 6, 0], [6, -5, 1, -8, 9, -2, 1, 2, 6], [3, 1, -5, 2, -3, -2, 2, -1, -3], [-12, -6, 2, 3, 10, 1, 1, -3, 0], [16, 8, 0, 5, -7, -5, 1, 0, -4], [-15, 3, -7, -4, 5, 1, 3, 5, 4], [-6, -6, 6, -3, 6, -1, 1, 5, 2], [12, 8, 4, 3, -7, -5, 1, 0, -10], [-8, 13, -8, 3, -15, -3, 1, 3, -3], [1, -9, 2, 3, 1, 0, 2, -9, -6], [-11, 1, -7, 1, -8, 4, 2, 3, 6], [21, 4, -3, 0, -7, -5, 1, 2, -1], [4, -1, 0, 1, -4, 6, -4, -4, 4], [-7, -3, 0, 0, 0, -2, -3, 1, 2], [-11, 8, -7, 8, -8, 0, -4, 5, -4], [12, -2, -2, -5, -2, 3, 5, -1, 2], [-7, -14, 6, 1, 0, 1, 4, -2, 1], [21, -15, 6, 0, 5, 4, 5, -3, 2], [-13, -11, 13, -3, 4, 1, 3, -2, -4], [-13, -7, -2, 0, 3, -2, -3, -5, 0], [4, -11, 1, 1, 12, 8, 3, -6, 3], [-9, 10, -7, 4, -9, 0, 0, 1, -1], [-3, -11, 5, -1, 10, 3, 0, 2, -2], [4, 14, 3, -2, -1, -7, 4, 3, 4], [-6, -1, -7, 6, 1, 0, 1, 2, -2], [-15, 2, 3, -5, -8, -2, 0, -5, 4], [-6, -4, -6, -5, 6, 5, -3, -3, 0], [-7, 1, 3, -6, -3, -5, -1, -4, -2], [1, -1, 1, -7, 5, 2, -4, 4, 4], [14, -1, -4, 1, -7, -1, 3, 3, 1], [13, 0, 4, -4, 2, 0, -1, 1, 1], [-13, -10, 5, 3, 7, -2, 0, 1, -3], [-15, -13, -4, 5, 3, 5, 0, 4, 2], [-16, 8, -9, 7, -8, 0, -1, 2, 0], [-3, -3, 2, 0, -2, 2, 1, 5, -2], [2, -3, 8, -8, 6, -5, 3, -5, -2], [-8, 6, 6, -12, 0, -6, 2, 0, -2], [4, 3, 1, 0, -9, 2, -3, -2, -8], [-10, 3, 3, -3, 16, 2, -1, -4, -3], [-20, 6, 3, -5, -6, -8, -5, -1, -4], [15, 6, -4, 3, -7, -1, -6, -4, -5], [-8, 1, 3, 0, -3, -3, -2, 5, 0], [20, -13, 9, -3, 4, 0, 1, -4, -1], [8, -2, 1, 4, 4, -1, -3, -5, -3], [3, -3, 5, 4, 7, -2, 2, -3, -3], [11, -10, 3, -5, -3, 2, -4, -7, -1], [13, 6, -2, 0, -6, 4, -1, -1, -7], [-4, 3, 5, 5, 1, -5, -2, -1, -8], [-13, -1, 3, 6, -1, -1, -3, 3, 0], [-12, 8, -4, -6, 7, -5, -3, 1, -3], [10, 13, -2, 0, 1, 0, 2, 6, -1], [10, 4, -8, 4, 2, 0, 0, 4, 6], [5, -12, 1, -4, 7, 3, -5, -8, 5], [6, 7, 1, 1, 2, -4, -3, -4, -3], [15, 2, -4, -2, -3, 3, 0, -6, -6], [3, -8, -3, -4, 1, 0, -1, 5, 7], [11, -4, 2, -7, 0, -5, 0, 4, 3], [-20, -2, 0, 2, 3, 7, -1, 3, 1], [-12, 11, -7, 1, -6, -4, -1, 8, -5], [11, -6, 5, 5, -2, -2, 2, 5, -3], [-5, -3, 1, -5, 13, 0, -7, 3, 1], [-5, 5, 1, -4, 1, 4, 0, 3, -7], [12, -5, -2, 5, -1, 4, 0, 2, 8], [3, 17, -8, 1, -1, 1, -4, 12, 0], [23, 3, 2, 11, -1, -2, 1, 5, -4], [-5, -3, 1, -7, 10, 0, 2, -1, 10], [5, 6, -2, 3, -15, 2, -5, -5, -10], [-12, 1, 0, -1, -2, -7, 1, 1, -4], [-1, 2, -6, 1, -6, 1, 6, 2, 7], [-8, 6, 3, -4, -5, -1, 0, -3, -2], [-17, -3, 3, -6, 7, -2, 2, 1, 3], [21, -9, 4, 3, -3, 5, 0, -2, 8], [3, 0, -3, 2, 2, 6, -4, -13, -2], [4, 2, 6, -5, -6, 1, 1, -9, -6], [10, -12, 1, 7, 5, 2, 1, 6, 0], [-10, -2, 1, 1, 16, 6, 5, 2, 2], [15, -11, 9, 2, 0, 3, -3, -2, 6], [16, -9, 0, 3, -10, 11, 2, 3, 2], [-6, 8, 4, -5, 6, 5, -7, -1, 2], [-9, 1, 5, -6, 10, -4, 0, 2, -1], [-16, -5, -3, 4, 0, 3, -2, 5, -1], [17, -6, 8, -5, 5, -1, 3, 0, 4], [23, 11, 3, -4, 5, 5, 1, -3, 4], [-3, 6, -8, -9, 12, -1, 4, 4, 5], [15, 9, -6, 2, -6, -5, -2, 0, 5], [-19, 17, -1, -6, -14, -2, -4, -3, 4], [12, 11, -9, -2, 4, 2, 3, 2, 1], [-23, 13, 0, 1, -9, -5, 4, 0, -6], [7, -1, 7, -2, 9, -5, -1, 3, 2], [-1, -9, 4, 1, 7, 2, -3, -7, 2], [8, -1, 4, -10, 0, -8, -6, -2, -4], [8, 8, 2, 1, -14, -3, -7, -3, -12], [14, 1, 3, 2, -11, -9, 2, -3, 2], [-8, -5, 1, 8, 6, 1, 6, 3, 1], [-12, 6, 2, -5, -10, -1, -1, 3, 8], [13, -21, 9, -8, 17, 2, 0, -1, 5], [24, -8, -6, 12, 7, 6, -2, 3, -2], [-30, 0, 1, -5, -1, -5, -8, -1, 3], [-23, 3, 3, 4, -9, -3, 3, 0, -5], [18, -3, 4, -5, -3, 2, 1, -14, -7], [14, 10, -2, 6, -7, -1, -5, -3, -5], [-6, 10, 0, -1, 8, 2, 0, 7, 7], [2, 1, 2, -5, 5, 0, -6, 0, -7], [35, 8, -6, 5, -3, 4, -1, 1, -6], [-8, 7, 1, 3, -10, -2, -1, 0, 3], [9, -4, 0, -4, 16, 2, 1, -7, -1], [3, 4, -6, 7, -6, 6, -5, 2, -4], [2, -7, -1, 8, -1, 6, -3, 2, -2], [-3, 6, 1, -7, -3, -4, 2, -5, 3], [29, 10, -1, -1, 3, 1, -4, -2, 3], [-14, 6, -3, -6, 9, -1, -6, 1, -2], [1, 2, 3, 6, -6, 5, -3, -1, -9], [-19, 9, -2, -5, -4, 5, -8, -4, -3], [12, 0, -6, 3, -3, 6, -10, 2, 5], [-2, 6, 7, -11, -2, -2, -10, -10, -7], [8, -4, 7, 0, -5, 9, -6, -13, 4], [32, -2, 2, -2, 7, 1, 1, 1, 5], [-21, -5, -4, 0, -1, 5, -4, 0, -3], [-12, 1, 10, -5, 0, 3, -1, 2, -3], [-9, 9, 6, -11, 3, -1, 0, -8, -6], [11, -8, 8, 14, -1, -1, 2, -4, -10], [18, -1, -6, 1, -4, 1, 1, 7, -2], [-14, 9, -3, -5, -3, 1, -6, 3, 2], [-6, 11, -3, 5, 6, 6, -3, 6, 1], [24, -5, 0, 1, -6, -2, 2, -6, 4], [-23, -2, -2, 4, -9, -5, 2, 2, -2], [-2, 16, -1, 4, -3, -4, -5, 0, -2], [-26, 6, 3, -8, -7, -3, -6, -7, 4], [-14, -1, 0, 0, 1, 2, 0, -2, -1], [-4, 1, -2, -2, -9, 0, -2, 4, 9], [10, 8, -4, 7, -8, -5, -1, 7, 0], [27, 9, -5, 0, 3, 0, -2, 1, 5], [30, 1, 5, 2, -13, 4, -3, -8, -2], [-4, 0, -4, -12, -8, 3, -3, -4, 1], [1, -6, -7, -4, -1, 1, 1, 8, 3], [5, 4, 4, -4, 2, -6, 3, 7, 1], [2, -7, -1, 0, 0, 3, 2, 1, 1], [-3, -3, -3, 12, 11, -4, 4, 11, 1], [12, -11, 4, -6, -2, -5, -1, -9, -4], [19, 1, -5, 13, -7, -1, 5, 0, -5], [6, 2, -8, 5, 10, -2, 6, 9, -1], [-23, 7, -4, 4, -9, 0, -5, 9, 2], [-3, 5, -5, -2, -14, 7, -9, -6, -2], [3, 10, 2, -1, -13, -9, 0, 0, -7], [8, 6, -3, -4, 7, 7, -2, 3, -2], [-2, 12, -2, 2, 1, 3, -5, -7, -9], [16, 2, -6, -1, 4, -7, 3, 3, 0], [4, 9, 0, 6, -1, -3, -2, -3, -13], [-16, -1, 4, 2, 12, 2, 5, 8, 2], [24, 2, 7, 1, -3, 5, 2, 3, -2], [9, -5, -9, 10, 5, 6, -6, 5, 1], [13, -2, 15, -2, 3, 0, -1, 3, 5], [-24, 10, -1, -10, 0, -2, 1, -12, -3], [-22, -2, 3, -1, 13, 5, -2, -7, 3], [-23, 10, -4, -4, -3, -1, 0, 4, 6], [5, 5, -2, -3, -4, -7, -2, -2, 1], [-17, -5, -2, -2, 6, 0, -1, 4, 12], [6, 13, 5, 0, -4, -11, 4, 7, 3], [-6, 5, 2, 0, 6, 6, -4, -13, -5], [7, -15, 11, -7, 5, -1, 1, -18, -1], [-2, -6, 1, -4, 3, 3, 2, 1, 4], [11, -10, 10, -3, 6, -5, 4, -10, -7], [-23, -1, -11, 4, 7, 0, 2, 3, 1], [24, -8, -1, -2, -2, 5, -2, 1, 8], [-15, 12, 4, 0, 6, 2, -1, 3, 5], [-2, 16, -6, 11, -21, -2, 4, 0, -5], [27, -3, 3, 4, -8, -3, 3, -2, -6], [21, 9, -7, -2, -2, 11, -1, -6, 6], [-5, -15, 1, 8, 8, 1, 5, -2, -4], [-13, -6, 4, -3, 9, 0, -9, -3, 2], [10, 2, 5, -11, -5, -1, -4, -13, -7], [16, 12, -6, -6, -2, -4, -2, -2, 2], [0, 4, 14, -10, 2, -12, 2, -4, -4], [-1, 12, -15, 2, -6, 8, 2, -1, 0], [-3, 3, -9, 2, -11, 2, -2, 7, 5], [5, 2, -10, -4, 5, 4, -8, 3, -4], [14, -3, -9, 7, -1, 1, 2, -1, 6], [-21, -15, -3, 3, 12, 2, -2, 5, 4], [-18, 7, -15, 1, -8, 4, 1, 0, -1], [32, -5, -1, 13, 5, 3, 2, 3, 0], [-3, 3, -7, 0, -5, 8, 0, 9, 11], [5, -15, 6, -7, 14, 6, -1, -11, 3], [3, -6, 3, 2, -1, -7, 3, -2, -11], [-1, 12, 0, 1, 4, -1, -6, 2, 3], [3, 5, -3, -6, -4, 4, 0, 2, 5], [-10, 11, -2, -6, -2, 2, -6, 4, 2], [-11, 7, 5, -7, 6, -7, 1, 5, 3], [9, -3, 6, -10, 5, 0, 1, 7, 2], [-16, 6, 8, -2, 1, -7, -1, -5, -5], [-1, -1, -4, -8, -13, -5, 2, -4, -4], [6, 2, -3, 8, -11, 0, 1, -5, -1], [-20, 6, -13, -1, -1, -4, 3, 8, 0], [-15, 0, 10, -1, 11, -2, -7, -1, 0], [-27, 13, -2, -4, 7, 6, -1, 1, -10], [12, -9, -5, -4, -3, 6, 1, 6, 4], [13, 13, 6, -1, 4, -1, 8, 2, -10], [-24, -3, 5, -6, 0, -1, 4, 1, 5], [-19, 16, -5, 0, -1, 1, 1, -2, 7], [2, -9, 19, -5, 10, -6, 3, -6, -3], [17, 13, -9, 1, -2, 7, 2, 8, 4], [11, -1, 9, 0, 7, -8, 4, 7, 7], [-9, -1, 10, -16, 2, 2, -3, -7, -2], [-6, -13, 3, -8, 15, 2, -5, -8, 6], [12, -13, -4, 2, -4, 0, 3, 0, 2], [12, -9, -9, 11, -7, 10, 3, 7, 11], [5, 0, 2, 11, 12, -4, 3, 5, 2], [-13, -7, 5, -1, 6, 0, 0, -5, 8], [-2, -7, -11, 4, 8, 1, 6, 9, -1], [2, 2, 3, -9, -4, 0, -5, 4, 8], [8, 0, 7, -13, 11, -4, 7, 4, -4], [-9, 3, 2, -3, 3, 3, 4, 10, 4], [-2, 2, 4, 7, -1, 2, 6, -2, 1], [14, 4, 0, -11, -5, 10, -6, -2, 9], [14, 17, -5, 7, -1, -7, 2, 9, -10], [29, 2, 5, -2, 3, -6, 4, -3, -4], [20, -5, -5, 13, -4, 0, 1, 4, 1], [-16, 8, -13, 7, 3, -4, -1, 2, -4], [21, -2, -3, 4, -4, 7, 10, 2, -6], [17, -1, 2, -9, 11, -2, -7, -9, -1], [4, -2, -3, 8, -6, -3, -1, 1, -9], [13, -1, 2, -5, -11, -3, 4, -6, 4], [4, -2, 8, -7, 4, -4, -8, -3, -11], [-24, -5, -3, 3, 1, -1, 2, 3, -4], [-8, 15, -4, -8, 9, -8, -6, -2, -1], [-4, -6, 9, 12, 0, 7, 2, -3, -4], [5, 4, 5, 3, -2, 1, -1, 14, 0], [28, 1, -7, 2, 5, 3, -5, 7, 8], [-20, 11, -3, 9, -13, 11, -4, -7, -10], [-32, 6, 4, 2, -1, 2, 0, -2, -7], [8, -23, 2, 4, 9, 0, 0, -4, 1], [-17, 2, -12, 7, -4, 3, -8, 12, 3], [-2, 6, -8, 12, -8, -4, 0, 2, -8], [10, -8, 7, -3, -7, -1, -6, -3, 3], [-1, -7, 2, -8, 13, 0, 9, -7, 6], [-1, -4, 9, -3, 5, 0, 4, 3, -1], [11, -10, 8, -4, -1, -6, -1, -4, -13], [12, -14, -3, -2, -5, -9, 8, -3, -4], [12, 9, -10, 5, -2, 6, -6, -2, 0], [-1, -16, -7, 5, 4, 8, 2, 9, 1], [26, -5, 2, 0, 9, -6, 6, 2, -3], [-12, 0, -14, -7, -4, -5, -7, 3, 2], [-19, 8, 4, 13, -1, 10, -3, -5, 0], [23, 1, 4, 1, -8, -1, -2, -4, -8], [22, -1, 0, -3, 9, 4, 4, 2, -8], [10, -9, -9, 7, -11, -7, 10, 3, -4], [-9, 7, -4, 6, -1, -1, 0, -7, -15], [-29, -7, 9, -8, 15, 2, -4, 5, 13], [24, -12, 8, 3, -1, -3, 3, -2, 10], [-23, 2, -8, 11, -5, -4, -5, -1, -2], [-43, 0, 1, 1, -1, 5, 1, 4, -1], [-29, 7, 1, -11, 6, -3, -9, -2, 1], [13, 6, -11, 8, -3, 9, -7, 8, -5], [14, 9, 10, 2, 7, -1, 1, -5, -4], [-1, -5, 0, -8, -6, -3, -4, -2, -5], [21, -14, 6, -8, 1, -5, 6, -6, 8]]
